==> factrainer-0.1.19-py3-none-any.whl: factrainer/lightgbm/dataset/dataset.py <==
from collections.abc import Generator

from factrainer.base.dataset import IndexableDataset, RowIndex, RowsAndColumns
from sklearn.model_selection._split import _BaseKFold

import lightgbm as lgb

from .equality_checker import LgbDatasetEqualityChecker
from .slicer import LgbDatasetSlicer


class LgbDataset(IndexableDataset):
    dataset: lgb.Dataset

    def k_fold_split(
        self, k_fold: _BaseKFold
    ) -> Generator[tuple[RowIndex, RowIndex], None, None]:
        for train_index, val_index in k_fold.split(self.dataset.data):  # type: ignore
            yield train_index.tolist(), val_index.tolist()

    def __getitem__(self, index: RowsAndColumns) -> "LgbDataset":
        match index:
            case int():
                return LgbDataset(
                    dataset=LgbDatasetSlicer(self.dataset.reference).slice(
                        self.dataset, [index]
                    )
                )
            case list():
                return LgbDataset(
                    dataset=LgbDatasetSlicer(self.dataset.reference).slice(
                        self.dataset, index
                    )
                )
            case slice():
                raise NotImplementedError
            case tuple():
                raise NotImplementedError
            case _:
                raise NotImplementedError

    def __eq__(self, value: object) -> bool:
        if not isinstance(value, LgbDataset):
            return False
        return LgbDatasetEqualityChecker().check(self.dataset, value.dataset)

==> factrainer-0.1.25-py3-none-any.whl: factrainer/lightgbm/dataset/dataset.py <==
from collections.abc import Generator

import numpy as np
from factrainer.base.dataset import IndexableDataset, RowIndex, Rows
from sklearn.model_selection._split import _BaseKFold

import lightgbm as lgb

from .slicer import LgbDatasetSlicer
from .types import IsPdDataFrame


class LgbDataset(IndexableDataset):
    dataset: lgb.Dataset

    def k_fold_split(
        self, k_fold: _BaseKFold
    ) -> Generator[tuple[RowIndex, RowIndex], None, None]:
        if isinstance(self.dataset.data, np.ndarray) or IsPdDataFrame().is_instance(
            self.dataset.data
        ):
            for train_index, val_index in k_fold.split(self.dataset.data):
                yield train_index, val_index
        else:
            raise NotImplementedError

    def __getitem__(self, index: Rows) -> "LgbDataset":
        match index:
            case int():
                return LgbDataset(
                    dataset=LgbDatasetSlicer(self.dataset.reference).slice(
                        self.dataset, [index]
                    )
                )
            case list():
                return LgbDataset(
                    dataset=LgbDatasetSlicer(self.dataset.reference).slice(
                        self.dataset, index
                    )
                )
            case np.ndarray():
                return LgbDataset(
                    dataset=LgbDatasetSlicer(self.dataset.reference).slice(
                        self.dataset, index
                    )
                )
            case slice():
                raise NotImplementedError
            case _:
                raise TypeError
